<template>
    <div class="aside-menu">
        <!-- <div
      class="logo_title"
      :style="$i18n.locale === 'en-US' ? {fontSize: '18px'} : ''"
      @click="goIndex"
    >
      {{ $t('login.title') }}
    </div> -->
        <div class="role-selector-wrap" v-if="roleList && roleList.length > 1">
            <span class="role-label">当前角色：</span>
            <el-select
                class="role-selector"
                v-model="roleCode"
                placeholder="请选择"
                size="small"
                @change="changeRole"
            >
                <el-option
                    v-for="item in roleList"
                    :key="item.roleCode"
                    :label="item.roleName"
                    :value="item.roleCode"
                >
                </el-option>
            </el-select>
        </div>
        <el-aside
            theme="dark"
            router
            unique-opened
            background-color="#393A40"
            text-color="#fff"
            active-text-color="#fff"
            :width="menuShow ? '231px' : '0px'"
            :class="[
                'aside-container',
                {short: roleList && roleList.length > 1},
            ]"
        >
            <el-scrollbar class="editScroll">
                <el-menu
                    ref="sidemenu"
                    unique-opened
                    class="el-menu-vertical"
                    :default-active="activeIndex"
                    @select="handleSelect"
                >
                    <div
                        v-for="menu in currentSubMenu"
                        active-text-color="#fff"
                        style="min-width: 230px; max-width: 230px"
                        :key="menu.alias"
                    >
                        <!-- + alias + '/'  -->
                        <el-submenu
                            :index="'/platLayout/' + menu.alias"
                            v-if="menu.children && menu.children.length > 0"
                            class="firstLevel"
                        >
                            <template slot="title">
                                <svgIcon
                                    icon-style="icon header-icon"
                                    :icon-class="
                                        menu.menuIcon ? menu.menuIcon : ''
                                    "
                                />
                                <span
                                    class="firstLevelTitle"
                                    style="font-size: 14px"
                                    >{{ menu.name }}</span
                                >
                            </template>
                            <!-- menu.alias + '/' + -->
                            <el-menu-item
                                :index="'/platLayout/' + submMenu.alias"
                                v-for="submMenu in menu.children"
                                :key="submMenu.alias"
                                class="subLevel"
                            >
                                <template slot="title">
                                    <svgIcon
                                        icon-style="icon header-icon"
                                        :icon-class="
                                            submMenu.menuIcon
                                                ? submMenu.menuIcon
                                                : ''
                                        "
                                    />
                                    <span class="subLevelTitle">{{
                                        submMenu.name
                                    }}</span>
                                </template>
                            </el-menu-item>
                        </el-submenu>
                        <el-menu-item
                            v-else
                            :index="'/platLayout/' + menu.alias"
                        >
                            <svgIcon
                                icon-style="icon header-icon"
                                :icon-class="menu.menuIcon ? menu.menuIcon : ''"
                            />
                            <span slot="title" class="firstLevelTitle">{{
                                menu.name
                            }}</span>
                        </el-menu-item>
                    </div>
                </el-menu>
            </el-scrollbar>
        </el-aside>
    </div>
</template>

<script>
import {mapState} from 'vuex'
import menu from '@/api/menu.js'
export default {
    props: {
        menuShow: {
            type: Boolean,
            default: true,
        },
    },
    data() {
        return {
            currentSubMenu: [],
            activeIndex: '',
            hasAuthTobigScreen: false,
            roleList: [],
            roleCode: '',
            admin: false,
            menuAll: [],
            platReady: undefined,
        }
    },
    watch: {
        // 监听路由，如果为首页等非菜单页面，取消菜单选中项
        $route(to, from) {
            console.log(to.meta.isHome);
            if (to.meta.isHome) {
                this.activeIndex = ''
            } else {
                this.filterSubMenu()
            }
        },
    },
    computed: {
        ...mapState({
            frontMenus: (state) => {
                return state.menu.frontMenus
            },
            roleMenus: (state) => {
                return state.menu.roleMenus
            },
        }),
    },
    mounted() {
        this.platReady = sessionStorage.getItem('platReady')
        this.getMenus()
        // this.getRoleList()
        this.$bus.$on('roterPush', (path) => {
            // console.log('监听到了')
            this.activeIndex = path
        })
    },
    beforeDestroy() {
        sessionStorage.removeItem('platReady')
    },
    methods: {
        changeRole(role) {
            this.roleCode = role
            sessionStorage.setItem('currentRoleCode', role)
            this.$store
                .dispatch('menu/actionsRoleMenu', this.roleCode)
                .then((data) => {
                    this.menuAll = data
                    this.filterSubMenu()
                    this.toFirstMenu(data)
                })
        },
        toFirstMenu(data) {
            let dataMenus =
                data && data.filter((item) => item.alias === 'normal')
            if (dataMenus && dataMenus.length !== 0) {
                if (
                    dataMenus[0].children.length !== 0 &&
                    dataMenus[0].children[0].children.length
                ) {
                    this.$router.push({
                        path: `/platLayout/${dataMenus[0].children[0].children[0].alias}`,
                    })
                    this.activeIndex = `/platLayout/${dataMenus[0].children[0].children[0].alias}`
                } else {
                    this.$router.push({
                        path: `/platLayout/${dataMenus[0].children[0].alias}`,
                    })
                    this.activeIndex = `/platLayout/${dataMenus[0].children[0].alias}`
                }
            } else {
                this.$router.push({
                    path: `/platLayout/empty`,
                })
            }
        },
        getRoleList() {
            let UserDetail = JSON.parse(
                sessionStorage.getItem('currentUserDetail')
            )
            if (!UserDetail) {
                this.$store
                    .dispatch('user/loadCurrentUserDetail')
                    .then((res) => {
                        UserDetail = res
                        this.roleList = UserDetail.roleList || []
                        sessionStorage.getItem(
                            'currentRoleCode',
                            this.roleList[0].roleCode
                        )
                        this.currentRoleCode(UserDetail)
                        this.getMenus()
                    })
            } else {
                this.roleList = UserDetail.roleList
                this.currentRoleCode(UserDetail)
                this.getMenus()
            }
        },
        currentRoleCode(UserDetail) {
            let defaultRole = sessionStorage.getItem('currentRoleCode')
            if (!defaultRole) {
                defaultRole = this.roleList[0].roleCode
                sessionStorage.setItem('currentRoleCode', defaultRole)
            }
            this.roleCode = defaultRole
            let account = UserDetail.user.account
            // 系统管理员使用frontMenus
            if (this.roleCode == 'sysRole' && account == 'admin') {
                this.admin = true
            } else {
                this.admin = false
            }
        },
        getMenus() {
            this.menuAll = []
            // if (!this.admin) {
            //     this.$store
            //         .dispatch('menu/actionsRoleMenu', this.roleCode)
            //         .then((data) => {
            //             this.menuAll = data
            //             this.filterSubMenu()
            //             if (!this.platReady) {
            //                 this.toFirstMenu(data)
            //                 this.platReady = 'ready'
            //                 sessionStorage.setItem('platReady', 'ready')
            //             }
            //         })
            // } else {
            //     this.$store.dispatch('menu/actionFrontMenus').then((data) => {
            //         this.menuAll = data
            //         this.filterSubMenu()
            //         if (!this.platReady) {
            //             this.toFirstMenu(data)
            //             this.platReady = 'ready'
            //             sessionStorage.setItem('platReady', 'ready')
            //         }
            //     })
            // }
            this.$store.dispatch('menu/actionFrontMenus').then((data) => {
                this.menuAll = data
                this.filterSubMenu()
                if (!this.platReady) {
                    this.toFirstMenu(data)
                    this.platReady = 'ready'
                    sessionStorage.setItem('platReady', 'ready')
                }
            })
        },
        goIndex() {
            if (!this.hasAuthTobigScreen) return
            let bigScreen = this.frontMenus.filter(
                (item) => item.alias === 'bigScreen'
            )
            let alise = bigScreen[0].children[0].alias
            this.$router.push({
                path: `/${alise}`,
            })
        },
        // 菜单的收折
        handleMenuCollapse() {
            this.$emit('update:menuShow', !this.menuShow)
        },
        handleSelect(path, isJump) {
            let alias
            let _this = this
            if (path && path.indexOf('/platLayout/href') == -1) {
                let i = path.lastIndexOf('/')
                alias = path.slice(i + 1)
            } else {
                alias = path.replace('/platLayout/', '')
            }
            menu.getMenuByAlias(alias, (m) => {
                m && _this.$emit('menuChange', m)
                if (m && m.openType == '2' && isJump) {
                    if (m.alias.indexOf('href/') == -1) {
                        let openPath = '/platLayout/' + m.alias
                        let routeUrl = this.$router.resolve({path: openPath})
                        window.open(routeUrl.href, '_blank')
                    } else {
                        let tempwindow = window.open()
                        tempwindow.location = m.href
                    }
                } else if (m && m.parent) {
                    this.$router.push(path)
                    this.activeIndex = path
                }
            })
        },
        // 筛选出选中菜单
        filterSubMenu() {
            console.log(this.menuAll, '角色菜单')
            if (this.menuAll && this.menuAll.length) {
                let currentMenu = this.menuAll.filter(
                    (item) => item.alias == 'normal'
                )[0]
                if (currentMenu) {
                    this.currentSubMenu = currentMenu.children
                } else {
                    this.currentSubMenu = []
                }
                console.log(this.$route.path,'this.$route.path');
                this.$refs.sidemenu.activeIndex = this.$route.path
                let bigScreen = this.roleMenus.filter(
                    (item) => item.alias === 'bigScreen'
                )
                this.hasAuthTobigScreen = bigScreen.length ? true : false
            } else {
                this.currentSubMenu = []
            }
        },
    },
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';
.logo_title {
  height: 75px;
  color: #fff;
  text-align: center;
  font-size: 24px;
  font-weight: bold;
  line-height: 75px;
  cursor: pointer;
}
.role-selector-wrap {
  width: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
  margin: 10px 0;
}
.role-label {
  font-size: 12px;
  color: $--menu-text;
}
.role-selector {
  width: 160px;
  /deep/ .el-input__inner {
    background-color: #616166;
    border-color: #616166;
    color: $--menu-text;
  }
  /deep/ .el-input.is-focus .el-input__inner,
  .el-input__inner:focus {
    border-color: #fff;
  }
}
/deep/.el-select .el-input__inner:focus {
  border-color: #fff;
}
.aside-container {
  //   height: calc(100% - 75px);
  height: calc(100%);
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
  background-color: $--menu-bg;
}
.aside-container.short {
  height: calc(100% - 125px);
}
.aside-menu {
  height: 100% !important;
  position: relative;
  background-color: $--menu-bg;
  box-shadow: 0 0px 12px 0 rgba($color: #000000, $alpha: 0.1);
}

.el-menu-vertical {
  height: 100% !important;
  .header-icon {
    margin-right: 10px;
    font-size: 16px;
    vertical-align: middle;
    margin-top: -1px;
  }
}
/deep/ .el-submenu__title {
  padding: 0 20px !important;
  // height: 46px;
  // line-height: 46px;
  color: $--menu-icon;
}
/deep/ .el-menu-item {
//   padding: 0 20px !important;
  // height: 56px;
  // line-height: 56px;
  span,
  svg {
    font-size: 14px !important;
    color: $--menu-text;
  }
  svg {
    color: $--menu-icon;
    font-size: 16px !important;
  }
}
/deep/ .el-submenu .el-menu-item {
    padding: 0 40px !important;
    box-sizing: border-box;
  // height: 46px;
  // line-height: 46px;
}

/deep/ .el-menu {
  border-right: none;
  background-color: $--menu-bg;
}
/deep/ .el-submenu__title .firstLevelTitle {
  font-size: 14px !important;
  color: $--menu-text;
}
.firstLevel .header-icon {
  font-size: 16px;
  margin-top: -4px;
}
.subLevel .header-icon {
  font-size: 16px;
  margin-top: -4px;
}
.el-submenu__title *,
.el-menu-item * {
  vertical-align: baseline;
}

.aside-container /deep/ .el-submenu{
    border-radius: 10px;
}
.aside-container /deep/ .el-submenu__title:hover {
    background-color: $--menu-hover !important;
    span,
    i,
    svg {
        color: #fff !important;
    }
}

.aside-container /deep/ .el-menu-item.is-active,
.aside-container /deep/ .el-menu-item:focus {
    background-color: $--menu-active !important;
    span,
    i,
    svg {
        color: #fff !important;
    }
}
.aside-container /deep/ .el-menu-item:hover {
    background-color: $--menu-hover !important;
    color: #fff;
}

.aside-container /deep/ .subLevel:hover {
    background-color: $--menu-hover !important;
    span,
    i,
    svg {
        color: #fff !important;
    }
}
.editScroll {
    height: 100%;
  // overflow-x: hidden;
}
/deep/ .el-scrollbar__wrap {
    height: calc(100% + 9px) !important;
    // height: 100%;
    // margin-right: 0px !important;
}
/deep/ .el-menu-item span {
    color: $--menu-text;
}
/deep/ .is-active {
    > .subLevelTitle {
        color: #fff;
    }
}
/deep/ .is-opened {
    .firstLevelTitle {
        color: $--menu-text;
    }
}
</style>
